@@ -101,7 +101,7 @@ def deduped(ms: Sequence[T], comp_func: Callable[[T, T], bool]) -> list[T]:
     return deduped_ms
 
 
-def batch_yield(ms: Iterable[T], batch_size: int) -> Generator[list[T]]:
+def batch_yield(ms: Iterable[T], batch_size: int) -> Generator[list[T], None, None]:
     """
     Splits the given input sequence into batches according to the specific batch size
 
